@@ -9,7 +9,7 @@ from rekuest.messages import Assignation, Provision
 from rekuest.api.schema import AssignationStatus, ProvisionFragment
 from rekuest.structures.serialization.actor import expand_inputs, shrink_outputs
 from rekuest.actors.contexts import AssignationContext
-
+from rekuest.actors.types import OnProvide, OnUnprovide
 logger = logging.getLogger(__name__)
 
 
@@ -25,10 +25,10 @@ async def async_none_unprovide():
 
 class FunctionalActor(BaseModel):
     assign: Callable[..., Any]
-    on_provide: Callable[[ProvisionFragment], Awaitable[Any]] = Field(
+    on_provide: OnProvide = Field(
         default=async_none_provide
     )
-    on_unprovide: Callable[[], Awaitable[Any]] = Field(default=async_none_unprovide)
+    on_unprovide: OnUnprovide = Field(default=async_none_unprovide)
 
     class Config:
         arbitrary_types_allowed = True
