@@ -1,6 +1,7 @@
 import contextvars
 from rekuest.api.schema import DefinitionInput
-from rekuest.actors.actify import reactify, Actifier
+from rekuest.actors.actify import reactify
+from rekuest.actors.types import Actifier
 from rekuest.structures.registry import (
     StructureRegistry,
     get_current_structure_registry,
@@ -10,7 +11,7 @@ from typing import Dict, List, Callable, Optional, Tuple
 from pydantic import Field
 from koil.composition import KoiledModel
 import json
-from rekuest.actors.builder import ActorBuilder
+from rekuest.actors.types import ActorBuilder
 
 
 current_definition_registry = contextvars.ContextVar(
