@@ -1,17 +1,14 @@
 from typing import Any
 from qtpy import QtCore
 from rekuest.agents.transport.base import AgentTransport
-from rekuest.api.schema import TemplateFragment
 from rekuest.messages import Provision
 from koil.qt import QtCoro
 from rekuest.actors.functional import FunctionalFuncActor
-from rekuest.rath import RekuestRath
 from qtpy import QtWidgets
 from rekuest.definition.registry import ActorBuilder
 from rekuest.definition.define import prepare_definition, DefinitionInput
 
 
-
 class QtInLoopBuilder(QtCore.QObject):
     """A function that takes a provision and an actor transport and returns an actor.
 
@@ -82,7 +79,6 @@ def qtinloopactifier(
         provision: Provision,
         transport: AgentTransport,
     ) -> Any:
-
         return in_loop_instance.build(
             provision, transport, definition
         )  # build an actor for this inloop instance
